summaryrefslogtreecommitdiff
path: root/glib
diff options
context:
space:
mode:
authorOwen Taylor <otaylor@redhat.com>2000-11-12 20:38:19 +0000
committerOwen Taylor <otaylor@src.gnome.org>2000-11-12 20:38:19 +0000
commit91d5e23f5fa8b9eda5cf07c3aedec46256183550 (patch)
tree83efff31961b6b5c1913761f9e25479d3a23f77d /glib
parent96b9935a7cc7d2cd67771451ebe8e1e5e230dc9f (diff)
downloadglib-91d5e23f5fa8b9eda5cf07c3aedec46256183550.tar.gz
template is a reserved word in C++ s/template/tmpl/.
Sun Nov 12 15:29:53 2000 Owen Taylor <otaylor@redhat.com> * gfileutils.[ch]: template is a reserved word in C++ s/template/tmpl/.
Diffstat (limited to 'glib')
-rw-r--r--glib/gfileutils.c24
-rw-r--r--glib/gfileutils.h2
2 files changed, 13 insertions, 13 deletions
diff --git a/glib/gfileutils.h b/glib/gfileutils.h
index 0e80543c6..9929ee152 100644
--- a/glib/gfileutils.h
+++ b/glib/gfileutils.h
@@ -84,7 +84,7 @@ gboolean g_file_get_contents (const gchar *filename,
int g_mkstemp (char *tmpl);
/* Wrapper for g_mkstemp */
-int g_file_open_tmp (const char *template,
+int g_file_open_tmp (const char *tmpl,
char **name_used,
GError **error);
diff --git a/glib/gfileutils.c b/glib/gfileutils.c
index b897e1b0a..e1a870b9d 100644
--- a/glib/gfileutils.c
+++ b/glib/gfileutils.c
@@ -586,20 +586,20 @@ g_mkstemp (char *tmpl)
/**
* g_file_open_tmp:
* @template: Template for file name, as in g_mkstemp, basename only
* @name_used: location to store actual name used
* @error: return location for a #GError
*
* Opens a file for writing in the preferred directory for temporary
* files (as returned by g_get_tmp_dir()).
*
* @template should be a string ending with six 'X' characters, as the
* parameter to g_mkstemp() (or mkstemp()). However, unlike these
* functions, the template should only be a basename, no directory
* components are allowed. If template is NULL, a default template is
* used.
*
* Note that in contrast to g_mkstemp() (and mkstemp()) @template is not
* modified, and might thus be a read-only literal string.
*
* The actual name used is returned in @name_used if non-NULL. This
@@ -610,7 +610,7 @@ g_mkstemp (char *tmpl)
* g_mkstemp() is returned.
**/
int
-g_file_open_tmp (const char *template,
+g_file_open_tmp (const char *tmpl,
char **name_used,
GError **error)
{
@@ -619,28 +619,28 @@ g_file_open_tmp (const char *template,
char *sep;
char *fulltemplate;
- if (template == NULL)
- template = ".XXXXXX";
+ if (tmpl == NULL)
+ tmpl = ".XXXXXX";
- if (strchr (template, G_DIR_SEPARATOR))
+ if (strchr (tmpl, G_DIR_SEPARATOR))
{
g_set_error (error,
G_FILE_ERROR,
G_FILE_ERROR_FAILED,
_("Template '%s' illegal, should not contain a '%s'"),
- template, G_DIR_SEPARATOR_S);
+ tmpl, G_DIR_SEPARATOR_S);
return -1;
}
- if (strlen (template) < 6 ||
- strcmp (template + strlen (template) - 6, "XXXXXX") != 0)
+ if (strlen (tmpl) < 6 ||
+ strcmp (tmpl + strlen (tmpl) - 6, "XXXXXX") != 0)
{
g_set_error (error,
G_FILE_ERROR,
G_FILE_ERROR_FAILED,
_("Template '%s' doesn end with XXXXXX"),
- template);
+ tmpl);
return -1;
}
@@ -651,7 +651,7 @@ g_file_open_tmp (const char *template,
else
sep = G_DIR_SEPARATOR_S;
- fulltemplate = g_strconcat (tmpdir, sep, template, NULL);
+ fulltemplate = g_strconcat (tmpdir, sep, tmpl, NULL);
retval = g_mkstemp (fulltemplate);
@@ -586,20 +586,20 @@ g_mkstemp (char *tmpl)
/**
* g_file_open_tmp:
- * @template: Template for file name, as in g_mkstemp, basename only
+ * @tmpl: Template for file name, as in g_mkstemp, basename only
* @name_used: location to store actual name used
* @error: return location for a #GError
@@ -586,20 +586,20 @@ g_mkstemp (char *tmpl)
* files (as returned by g_get_tmp_dir()).
*
- * @template should be a string ending with six 'X' characters, as the
+ * @tmpl should be a string ending with six 'X' characters, as the
* parameter to g_mkstemp() (or mkstemp()). However, unlike these
* functions, the template should only be a basename, no directory
@@ -586,20 +586,20 @@ g_mkstemp (char *tmpl)
* used.
*
- * Note that in contrast to g_mkstemp() (and mkstemp()) @template is not
+ * Note that in contrast to g_mkstemp() (and mkstemp()) @tmpl is not
* modified, and might thus be a read-only literal string.
*